@@ -1173,6 +1173,11 @@ function adjustZoom(delta) {
 }
 function startElectron() {
   console.info('App starting...');
+
+  // Increase max listeners to prevent false positive warnings
+  // The app legitimately needs multiple IPC listeners (currently 11)
+  // Default is 10, setting to 20 provides headroom for future additions
+  _electron.ipcMain.setMaxListeners(20);
   let appVersion;
   if (isDev && process.env.HEADLAMP_APP_VERSION) {
     appVersion = process.env.HEADLAMP_APP_VERSION;
